==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/Stratimikos/StratimikosTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Stratimikos::stratimikosifpack" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosifpack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosifpack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosifpack.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikosifpack.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosifpack )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosifpack "${_IMPORT_PREFIX}/lib/libstratimikosifpack.so.15.0" )

# Import target "Stratimikos::stratimikosml" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosml.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikosml.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosml )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosml "${_IMPORT_PREFIX}/lib/libstratimikosml.so.15.0" )

# Import target "Stratimikos::stratimikosamesos" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosamesos APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosamesos PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosamesos.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikosamesos.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosamesos )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosamesos "${_IMPORT_PREFIX}/lib/libstratimikosamesos.so.15.0" )

# Import target "Stratimikos::stratimikosaztecoo" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosaztecoo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosaztecoo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosaztecoo.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikosaztecoo.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosaztecoo )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosaztecoo "${_IMPORT_PREFIX}/lib/libstratimikosaztecoo.so.15.0" )

# Import target "Stratimikos::stratimikosamesos2" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosamesos2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosamesos2 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosamesos2.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikosamesos2.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosamesos2 )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosamesos2 "${_IMPORT_PREFIX}/lib/libstratimikosamesos2.so.15.0" )

# Import target "Stratimikos::stratimikosbelos" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosbelos APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosbelos PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosbelos.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikosbelos.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosbelos )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosbelos "${_IMPORT_PREFIX}/lib/libstratimikosbelos.so.15.0" )

# Import target "Stratimikos::stratimikos" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikos APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikos PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikos.so.15.0"
  IMPORTED_SONAME_RELEASE "libstratimikos.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikos )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikos "${_IMPORT_PREFIX}/lib/libstratimikos.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/Stratimikos/StratimikosTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Stratimikos::stratimikosifpack" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosifpack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosifpack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosifpack.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikosifpack.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosifpack )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosifpack "${_IMPORT_PREFIX}/lib/libstratimikosifpack.so.15.1.1" )

# Import target "Stratimikos::stratimikosml" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosml.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikosml.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosml )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosml "${_IMPORT_PREFIX}/lib/libstratimikosml.so.15.1.1" )

# Import target "Stratimikos::stratimikosamesos" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosamesos APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosamesos PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosamesos.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikosamesos.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosamesos )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosamesos "${_IMPORT_PREFIX}/lib/libstratimikosamesos.so.15.1.1" )

# Import target "Stratimikos::stratimikosaztecoo" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosaztecoo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosaztecoo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosaztecoo.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikosaztecoo.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosaztecoo )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosaztecoo "${_IMPORT_PREFIX}/lib/libstratimikosaztecoo.so.15.1.1" )

# Import target "Stratimikos::stratimikosamesos2" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosamesos2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosamesos2 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosamesos2.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikosamesos2.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosamesos2 )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosamesos2 "${_IMPORT_PREFIX}/lib/libstratimikosamesos2.so.15.1.1" )

# Import target "Stratimikos::stratimikosbelos" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikosbelos APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikosbelos PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikosbelos.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikosbelos.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikosbelos )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikosbelos "${_IMPORT_PREFIX}/lib/libstratimikosbelos.so.15.1.1" )

# Import target "Stratimikos::stratimikos" for configuration "RELEASE"
set_property(TARGET Stratimikos::stratimikos APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Stratimikos::stratimikos PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstratimikos.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstratimikos.so.15"
  )

list(APPEND _cmake_import_check_targets Stratimikos::stratimikos )
list(APPEND _cmake_import_check_files_for_Stratimikos::stratimikos "${_IMPORT_PREFIX}/lib/libstratimikos.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
